'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Mention = require('./Mention');

var _Mention2 = _interopRequireDefault(_Mention);

var _MentionSearch = require('./MentionSearch');

var _MentionSearch2 = _interopRequireDefault(_MentionSearch);

var _mentionStrategy = require('./mentionStrategy');

var _mentionStrategy2 = _interopRequireDefault(_mentionStrategy);

var _mentionSearchStrategy = require('./mentionSearchStrategy');

var _mentionSearchStrategy2 = _interopRequireDefault(_mentionSearchStrategy);

var _decorateComponentWithProps = require('../utils/decorateComponentWithProps');

var _decorateComponentWithProps2 = _interopRequireDefault(_decorateComponentWithProps);

var _immutable = require('immutable');

var _mentionStyles = require('./mentionStyles.css');

var _mentionStyles2 = _interopRequireDefault(_mentionStyles);

var _autocompleteStyles = require('./autocompleteStyles.css');

var _autocompleteStyles2 = _interopRequireDefault(_autocompleteStyles);

var _autocompleteEntryStyles = require('./autocompleteEntryStyles.css');

var _autocompleteEntryStyles2 = _interopRequireDefault(_autocompleteEntryStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultTheme = (0, _immutable.Map)({
  mention: _mentionStyles2.default.mention,

  autocomplete: _autocompleteStyles2.default.autocomplete,
  autocompletePopover: _autocompleteStyles2.default.autocompletePopover,

  autocompleteEntry: _autocompleteEntryStyles2.default.autocompleteEntry,
  autocompleteEntryFocused: _autocompleteEntryStyles2.default.autocompleteEntryFocused,
  autocompleteEntryText: _autocompleteEntryStyles2.default.autocompleteEntryText,
  autocompleteEntryAvatar: _autocompleteEntryStyles2.default.autocompleteEntryAvatar
});

var callbacks = {
  keyBindingFn: undefined,
  handleKeyCommand: undefined,
  onDownArrow: undefined,
  onUpArrow: undefined,
  onEscape: undefined,
  handleReturn: undefined,
  onChange: undefined
};

var ariaProps = {
  role: 'combobox',
  ariaAutoComplete: 'list',
  ariaHasPopup: 'false',
  ariaExpanded: 'false',
  ariaOwneeID: 'mentions-select', // optional
  ariaActiveDescendantID: undefined };

// optional
var mentionPlugin = function mentionPlugin() {
  var config = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  // Styles are overwritten instead of merged as merging causes a lot of confusion.
  //
  // Why? Because when merging a developer needs to know all of the underlying
  // styles which needs a deep dive into the code. Merging also makes it prone to
  // errors when upgrading as basically every styling change would become a major
  // breaking change. 1px of an increased padding can break a whole layout.
  var theme = config.theme ? config.theme : defaultTheme;
  var mentionSearchProps = {
    ariaProps: ariaProps,
    callbacks: callbacks,
    mentions: config.mentions,
    theme: theme
  };
  return {
    pluginProps: {
      decorators: [{
        strategy: _mentionStrategy2.default,
        component: (0, _decorateComponentWithProps2.default)(_Mention2.default, { theme: theme })
      }, {
        strategy: _mentionSearchStrategy2.default,
        component: (0, _decorateComponentWithProps2.default)(_MentionSearch2.default, mentionSearchProps)
      }],
      getEditorProps: function getEditorProps() {
        return ariaProps;
      },
      keyBindingFn: function keyBindingFn(keyboardEvent) {
        return callbacks.keyBindingFn && callbacks.keyBindingFn(keyboardEvent);
      },
      handleKeyCommand: function handleKeyCommand(command) {
        return callbacks.handleKeyCommand && callbacks.handleKeyCommand(command);
      },
      onDownArrow: function onDownArrow(keyboardEvent) {
        return callbacks.onDownArrow && callbacks.onDownArrow(keyboardEvent);
      },
      onUpArrow: function onUpArrow(keyboardEvent) {
        return callbacks.onUpArrow && callbacks.onUpArrow(keyboardEvent);
      },
      onEscape: function onEscape(keyboardEvent) {
        return callbacks.onEscape && callbacks.onEscape(keyboardEvent);
      },
      handleReturn: function handleReturn(keyboardEvent) {
        return callbacks.handleReturn && callbacks.handleReturn(keyboardEvent);
      },
      onChange: function onChange(editorState) {
        if (callbacks.onChange) return callbacks.onChange(editorState);
        return editorState;
      }
    }
  };
};

exports.default = mentionPlugin;